==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PageRootEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomizablePage;
import java.net.URI;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PageRootEmbedded
 */
@JsonPropertyOrder({ PageRootEmbedded.JSON_PROPERTY_DEFAULT, PageRootEmbedded.JSON_PROPERTY_CUSTOMIZED,
        PageRootEmbedded.JSON_PROPERTY_CUSTOMIZED_URL, PageRootEmbedded.JSON_PROPERTY_PREVIEW,
        PageRootEmbedded.JSON_PROPERTY_PREVIEW_URL })
@JsonTypeName("PageRoot__embedded")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PageRootEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DEFAULT = "default";
    private CustomizablePage _default;

    public static final String JSON_PROPERTY_CUSTOMIZED = "customized";
    private CustomizablePage customized;

    public static final String JSON_PROPERTY_CUSTOMIZED_URL = "customizedUrl";
    private URI customizedUrl;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private CustomizablePage preview;

    public static final String JSON_PROPERTY_PREVIEW_URL = "previewUrl";
    private URI previewUrl;

    public PageRootEmbedded() {
    }

    public PageRootEmbedded _default(CustomizablePage _default) {

        this._default = _default;
        return this;
    }

    /**
     * Get _default
     *
     * @return _default
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getDefault() {
        return _default;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefault(CustomizablePage _default) {
        this._default = _default;
    }

    public PageRootEmbedded customized(CustomizablePage customized) {

        this.customized = customized;
        return this;
    }

    /**
     * Get customized
     *
     * @return customized
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getCustomized() {
        return customized;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomized(CustomizablePage customized) {
        this.customized = customized;
    }

    public PageRootEmbedded customizedUrl(URI customizedUrl) {

        this.customizedUrl = customizedUrl;
        return this;
    }

    /**
     * Get customizedUrl
     *
     * @return customizedUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public URI getCustomizedUrl() {
        return customizedUrl;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizedUrl(URI customizedUrl) {
        this.customizedUrl = customizedUrl;
    }

    public PageRootEmbedded preview(CustomizablePage preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(CustomizablePage preview) {
        this.preview = preview;
    }

    public PageRootEmbedded previewUrl(URI previewUrl) {

        this.previewUrl = previewUrl;
        return this;
    }

    /**
     * Get previewUrl
     *
     * @return previewUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public URI getPreviewUrl() {
        return previewUrl;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreviewUrl(URI previewUrl) {
        this.previewUrl = previewUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PageRootEmbedded pageRootEmbedded = (PageRootEmbedded) o;
        return Objects.equals(this._default, pageRootEmbedded._default)
                && Objects.equals(this.customized, pageRootEmbedded.customized)
                && Objects.equals(this.customizedUrl, pageRootEmbedded.customizedUrl)
                && Objects.equals(this.preview, pageRootEmbedded.preview)
                && Objects.equals(this.previewUrl, pageRootEmbedded.previewUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_default, customized, customizedUrl, preview, previewUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PageRootEmbedded {\n");
        sb.append("    _default: ").append(toIndentedString(_default)).append("\n");
        sb.append("    customized: ").append(toIndentedString(customized)).append("\n");
        sb.append("    customizedUrl: ").append(toIndentedString(customizedUrl)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("    previewUrl: ").append(toIndentedString(previewUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/PageRootEmbedded.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CustomizablePage;
import java.net.URI;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PageRootEmbedded
 */
@JsonPropertyOrder({ PageRootEmbedded.JSON_PROPERTY_DEFAULT, PageRootEmbedded.JSON_PROPERTY_CUSTOMIZED,
        PageRootEmbedded.JSON_PROPERTY_CUSTOMIZED_URL, PageRootEmbedded.JSON_PROPERTY_PREVIEW,
        PageRootEmbedded.JSON_PROPERTY_PREVIEW_URL })
@JsonTypeName("PageRoot__embedded")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PageRootEmbedded implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_DEFAULT = "default";
    private CustomizablePage _default;

    public static final String JSON_PROPERTY_CUSTOMIZED = "customized";
    private CustomizablePage customized;

    public static final String JSON_PROPERTY_CUSTOMIZED_URL = "customizedUrl";
    private URI customizedUrl;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private CustomizablePage preview;

    public static final String JSON_PROPERTY_PREVIEW_URL = "previewUrl";
    private URI previewUrl;

    public PageRootEmbedded() {
    }

    public PageRootEmbedded _default(CustomizablePage _default) {

        this._default = _default;
        return this;
    }

    /**
     * Get _default
     *
     * @return _default
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getDefault() {
        return _default;
    }

    @JsonProperty(JSON_PROPERTY_DEFAULT)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setDefault(CustomizablePage _default) {
        this._default = _default;
    }

    public PageRootEmbedded customized(CustomizablePage customized) {

        this.customized = customized;
        return this;
    }

    /**
     * Get customized
     *
     * @return customized
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getCustomized() {
        return customized;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomized(CustomizablePage customized) {
        this.customized = customized;
    }

    public PageRootEmbedded customizedUrl(URI customizedUrl) {

        this.customizedUrl = customizedUrl;
        return this;
    }

    /**
     * Get customizedUrl
     *
     * @return customizedUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CUSTOMIZED_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public URI getCustomizedUrl() {
        return customizedUrl;
    }

    @JsonProperty(JSON_PROPERTY_CUSTOMIZED_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCustomizedUrl(URI customizedUrl) {
        this.customizedUrl = customizedUrl;
    }

    public PageRootEmbedded preview(CustomizablePage preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CustomizablePage getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(CustomizablePage preview) {
        this.preview = preview;
    }

    public PageRootEmbedded previewUrl(URI previewUrl) {

        this.previewUrl = previewUrl;
        return this;
    }

    /**
     * Get previewUrl
     *
     * @return previewUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public URI getPreviewUrl() {
        return previewUrl;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreviewUrl(URI previewUrl) {
        this.previewUrl = previewUrl;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PageRootEmbedded pageRootEmbedded = (PageRootEmbedded) o;
        return Objects.equals(this._default, pageRootEmbedded._default)
                && Objects.equals(this.customized, pageRootEmbedded.customized)
                && Objects.equals(this.customizedUrl, pageRootEmbedded.customizedUrl)
                && Objects.equals(this.preview, pageRootEmbedded.preview)
                && Objects.equals(this.previewUrl, pageRootEmbedded.previewUrl);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_default, customized, customizedUrl, preview, previewUrl);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PageRootEmbedded {\n");
        sb.append("    _default: ").append(toIndentedString(_default)).append("\n");
        sb.append("    customized: ").append(toIndentedString(customized)).append("\n");
        sb.append("    customizedUrl: ").append(toIndentedString(customizedUrl)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("    previewUrl: ").append(toIndentedString(previewUrl)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
